@@ -1,5 +1,5 @@
 import json
-from property import (CustomProperty, StrProperty, BoolProperty)
+from property import *
 
 
 class SimConf:
